.. module:: pymeasure.instruments.hp

###############
Hewlett Packard
###############

This section contains specific documentation on the Hewlett Packard instruments that are implemented. If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

If the instrument you are looking for is not here, also check :doc:`Agilent<../agilent/index>` or :doc:`Keysight<../keysight/index>` for newer instruments. 

.. toctree::
   :maxdepth: 2

   hp33120A
   hp34401A
   hp3437A
   hp3478A
   hp8116A
   hp856xx
   hp8657B
   hp11713A
   hp437B
   hplegacyinstrument
   hpsystempsu
